@@ -5,8 +5,9 @@ use warnings;
 package Sub::HandlesVia::Toolkit::Mite;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.027';
+our $VERSION   = '0.028';
 
+use Types::Standard -types, -is;
 use Sub::HandlesVia::Toolkit;
 our @ISA = 'Sub::HandlesVia::Toolkit';
 
@@ -25,16 +26,39 @@ sub install_has_wrapper {
 	no warnings 'redefine';
 	
 	my $orig = \&{ "$target\::has" };
+	my $uses_mite = ${ "$target\::USES_MITE" };
+	
 	*{ "$target\::has" } = sub {
 		my ( $names, %spec ) = @_;
 		return $orig->($names, %spec) unless $spec{handles}; # shortcut
 		
+		my @shv;
 		$names = [ $names ] unless ref($names);
 		for my $name ( @$names ) {
 			my $shv = $me->clean_spec( $target, $name, \%spec );
 			$SPECS{$target}{$name} = \%spec;
 			$orig->( $name, %spec );
-			$me->install_delegations( $shv ) if $shv;
+			push @shv, $shv if $shv;
+		}
+		
+		if ( $ENV{MITE_COMPILE} ) {
+			return;
+		}
+		
+		if ( $uses_mite eq 'Mite::Role' ) {
+			require Role::Hooks;
+			'Role::Hooks'->after_apply( $target, sub {
+				my ( $from, $to ) = @_;
+				return if 'Role::Hooks'->is_role( $to );
+				for my $shv ( @shv ) {
+					$me->install_delegations( { %$shv, target => $to } );
+				}
+			} );
+		}
+		else {
+			for my $shv ( @shv ) {
+				$me->install_delegations( $shv );
+			}
 		}
 		
 		return;
